# Copyright 1999-2018 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2

EAPI=5
PYTHON_COMPAT=( python2_7 python3_5)
PYTHON_REQ_USE="threads(+)" # threads for waf

inherit eutils xdg-utils gnome2-utils python-single-r1 waf-utils

DESCRIPTION="kupfer, a smart, quick launcher"
HOMEPAGE="https://kupferlauncher.github.io/"
SRC_URI="https://github.com/kupferlauncher/${PN}/releases/download/v${PV}/${PN}-v${PV}.tar.xz"

LICENSE="Apache-2.0 GPL-2 GPL-3"
SLOT="0"
KEYWORDS="~amd64 ~x86"
IUSE="gnome gnome-keyring +keybinder doc appindicator nautilus"

COMMON_DEPEND="${PYTHON_DEPS}
	dev-python/pygtk
	dev-python/pyxdg[${PYTHON_USEDEP}]
	dev-python/dbus-python[${PYTHON_USEDEP}]
	dev-python/pygobject:=[${PYTHON_USEDEP}]
	gnome? ( dev-python/libgnome-python )
	gnome-keyring? ( dev-python/gnome-keyring-python )
	dev-python/setproctitle[${PYTHON_USEDEP}]
	dev-python/libwnck-python
	dev-python/pycairo[${PYTHON_USEDEP}]"
DEPEND="${COMMON_DEPEND}
	dev-python/docutils[${PYTHON_USEDEP}]
	doc? ( app-text/gnome-doc-utils )
	dev-util/intltool"
RDEPEND="${COMMON_DEPEND}
	keybinder? ( dev-libs/keybinder[python] )
	appindicator? ( dev-libs/libappindicator )
	nautilus? ( gnome-base/nautilus )"

REQUIRED_USE="${PYTHON_REQUIRED_USE}"

S="${WORKDIR}/${PN}-v${PV}"

src_prepare() {
	epatch "${FILESDIR}/${P}-remove-errcheck.patch"

	if ! use doc; then
		sed -i -e 's/bld.env\["XML2PO"\]/False/' help/wscript || die
	fi
}

src_configure() {
	local myopts=""
	use nautilus || myopts="--no-install-nautilus-extension"
	waf-utils_src_configure --no-update-mime --no-update-icon-cache --nopyc ${myopts}
}

src_compile() {
	waf-utils_src_compile
}

src_install() {
	waf-utils_src_install
}

pkg_preinst() {
	gnome2_icon_savelist
}

pkg_postinst() {
	fdo-mime_desktop_database_update
	fdo-mime_mime_database_update
	gnome2_icon_cache_update
	elog "Some Kupfer plugins require optional runtime dependencies"
	elog "check ${HOMEPAGE} for details"
	elog "e.g. dev-python/gdata"
}

pkg_postrm() {
	fdo-mime_desktop_database_update
	fdo-mime_mime_database_update
	gnome2_icon_cache_update
}
